import { CodeMirrorLSPFeature, CommandEntryPoint } from '../feature';
import { InputDialog } from '@jupyterlab/apputils';
export class Rename extends CodeMirrorLSPFeature {
    register() {
        this.connection_handlers.set('renamed', this.handleRename.bind(this));
        super.register();
    }
    handleRename(workspaceEdit) {
        this.apply_edit(workspaceEdit);
    }
}
Rename.commands = [
    {
        id: 'rename-symbol',
        execute: ({ connection, virtual_position, document }) => {
            let old_value = document.getTokenAt(virtual_position).string;
            InputDialog.getText({
                title: 'Rename to',
                text: old_value,
                okLabel: 'Rename'
            })
                .then(value => {
                connection.rename(virtual_position, value.value);
            })
                .catch(console.warn);
        },
        is_enabled: ({ connection }) => connection.isRenameSupported(),
        label: 'Rename symbol',
        attach_to: new Set([
            // notebooks are not supported yet
            CommandEntryPoint.FileEditorContextMenu
        ])
    }
];
//# sourceMappingURL=rename.js.map