import { CodeMirrorEditorFactory } from '@jupyterlab/codemirror';
import { LSPConnection } from '../../connection';
import { CodeEditor } from '@jupyterlab/codeeditor';
import { VirtualFileEditor } from '../../virtual/editors/file_editor';
export class FeatureTestEnvironment {
    constructor(language = () => 'python', path = () => 'dummy.py', file_extension = () => 'py') {
        this.language = language;
        this.path = path;
        this.file_extension = file_extension;
        const factoryService = new CodeMirrorEditorFactory();
        this.connections = new Map();
        this.host = document.createElement('div');
        document.body.appendChild(this.host);
        let model = new CodeEditor.Model();
        this.ce_editor = factoryService.newDocumentEditor({
            host: this.host,
            model
        });
        this.virtual_editor = new VirtualFileEditor(language, file_extension, path, this.ce_editor.editor);
    }
    init_feature(feature_type, register = true) {
        let dummy_components_manager = this.create_dummy_components();
        let connection = this.create_dummy_connection();
        const feature = new feature_type(this.virtual_editor, this.virtual_editor.virtual_document, connection, dummy_components_manager);
        this.connections.set(feature, connection);
        if (register) {
            feature.register();
        }
        return feature;
    }
    dispose_feature(feature) {
        let connection = this.connections.get(feature);
        connection.close();
        feature.is_registered = false;
    }
    create_dummy_connection() {
        return new LSPConnection({
            languageId: this.language(),
            serverUri: '',
            documentUri: '/' + this.path,
            rootUri: '/',
            documentText: () => {
                this.virtual_editor.update_documents().catch(console.log);
                return this.virtual_editor.virtual_document.value;
            }
        });
    }
    create_dummy_components() {
        return {
            invoke_completer: () => {
                // nothing yet
            },
            create_tooltip: () => {
                return {};
            },
            remove_tooltip: () => {
                // nothing yet
            },
            jumper: null
        };
    }
    dispose() {
        document.body.removeChild(this.host);
        this.ce_editor.dispose();
    }
}
//# sourceMappingURL=testutils.js.map