import { expect } from 'chai';
import { VirtualEditor } from './editor';
import { RegExpForeignCodeExtractor } from '../extractors/regexp';
class VirtualEditorImplementation extends VirtualEditor {
    get_cm_editor(position) {
        return undefined;
    }
    get_editor_index(position) {
        return 0;
    }
    transform_editor_to_root(cm_editor, position) {
        return undefined;
    }
    addEventListener(type, listener) {
        // nothing yet
    }
    perform_documents_update() {
        // nothing yet
    }
    forEveryBlockEditor(callback) {
        callback(this.cm_editor);
    }
}
describe('VirtualEditor', () => {
    let r_line_extractor = new RegExpForeignCodeExtractor({
        language: 'R',
        pattern: '(^|\n)%R (.*)\n?',
        extract_to_foreign: '$2',
        keep_in_host: true,
        is_standalone: false,
        file_extension: 'R'
    });
    let editor = new VirtualEditorImplementation(() => 'python', () => 'py', () => 'test.ipynb', {}, { python: [r_line_extractor] });
    describe('#document_at_root_position()', () => {
        it('returns correct document', () => {
            let cm_editor_for_cell_1 = {};
            let cm_editor_for_cell_2 = {};
            editor.virtual_document.append_code_block('test line in Python 1\n%R test line in R 1', cm_editor_for_cell_1);
            editor.virtual_document.append_code_block('test line in Python 2\n%R test line in R 2', cm_editor_for_cell_2);
            // The first (Python) line in the first block
            let root_position = { line: 0, ch: 0 };
            let document = editor.document_at_root_position(root_position);
            let virtual_position = editor.root_position_to_virtual_position(root_position);
            expect(document).to.equal(editor.virtual_document);
            expect(virtual_position.line).to.equal(0);
            // The second (Python | R) line in the first block - Python fragment
            root_position = { line: 1, ch: 0 };
            document = editor.document_at_root_position(root_position);
            virtual_position = editor.root_position_to_virtual_position(root_position);
            expect(document).to.equal(editor.virtual_document);
            expect(virtual_position.line).to.equal(1);
            // The second (Python | R) line in the first block - R fragment
            root_position = { line: 1, ch: 3 };
            document = editor.document_at_root_position(root_position);
            virtual_position = editor.root_position_to_virtual_position(root_position);
            expect(document).to.not.equal(editor.virtual_document);
            expect(virtual_position.line).to.equal(0);
            // The first (Python) line in the second block
            root_position = { line: 2, ch: 0 };
            document = editor.document_at_root_position(root_position);
            virtual_position = editor.root_position_to_virtual_position(root_position);
            expect(document).to.equal(editor.virtual_document);
            expect(virtual_position.line).to.equal(2 + 2);
            // The second (Python | R) line in the second block - Python fragment
            root_position = { line: 3, ch: 0 };
            document = editor.document_at_root_position(root_position);
            virtual_position = editor.root_position_to_virtual_position(root_position);
            expect(document).to.equal(editor.virtual_document);
            expect(virtual_position.line).to.equal(2 + 2 + 1);
            // The second (Python | R) line in the second block - R fragment
            root_position = { line: 3, ch: 3 };
            document = editor.document_at_root_position(root_position);
            virtual_position = editor.root_position_to_virtual_position(root_position);
            expect(document).to.not.equal(editor.virtual_document);
            // 0 + 1 (next line) + 2 (between-block spacing)
            expect(virtual_position.line).to.equal(1 + 2);
        });
    });
});
//# sourceMappingURL=editor.spec.js.map